@@ -557,6 +557,12 @@ bool BackgroundParser::isQueued(KUrl url) const {
     return d->m_documents.contains(url) || d->m_delayedParseJobs.contains(url);
 }
 
+int BackgroundParser::queuedCount() const
+{
+    QMutexLocker lock(&d->m_mutex);
+    return d->m_documents.count() + d->m_delayedParseJobs.count();
+}
+
 void BackgroundParser::setNeededPriority(int priority)
 {
     QMutexLocker lock(&d->m_mutex);
@@ -635,14 +641,15 @@ QList< KUrl > BackgroundParser::managedDocuments()
 
 void BackgroundParser::addManagedTopRange(const KUrl& document, KTextEditor::SmartRange* range)
 {
-    range->addWatcher(this);
+    Q_ASSERT(range);
+    range->addWatcher(this); ///@todo Smart-lock
     QMutexLocker l(&d->m_mutex);
     d->m_managedRanges.insert(range, document);
 }
 
 void BackgroundParser::removeManagedTopRange(KTextEditor::SmartRange* range)
 {
-   range->removeWatcher(this);
+   range->removeWatcher(this); ///@todo Smart-lock
    QMutexLocker l(&d->m_mutex);
    d->m_managedRanges.remove(range);
 }
