@@ -52,7 +52,7 @@ class KDEVPLATFORMLANGUAGE_EXPORT IndexedDeclarationHandler {
     inline static void createFreeItem(IndexedDeclaration& data) {
         data = IndexedDeclaration();
         data.setIsDummy(true);
-        data.setDummyData(qMakePair(0u, 0u)); //Since we substract 1, this equals children -1, -1
+        data.setDummyData(qMakePair(0u, 0u)); //Since we subtract 1, this equals children -1, -1
     }
     //Copies this item into the given one
     inline static void copyTo(const IndexedDeclaration& m_data, IndexedDeclaration& data) {
@@ -85,7 +85,7 @@ class KDEVPLATFORMLANGUAGE_EXPORT IndexedDUContextHandler {
     inline static void createFreeItem(IndexedDUContext& data) {
         data = IndexedDUContext();
         data.setIsDummy(true);
-        data.setDummyData(qMakePair(0u, 0u)); //Since we substract 1, this equals children -1, -1
+        data.setDummyData(qMakePair(0u, 0u)); //Since we subtract 1, this equals children -1, -1
     }
     //Copies this item into the given one
     inline static void copyTo(const IndexedDUContext& m_data, IndexedDUContext& data) {
@@ -100,6 +100,26 @@ class KDEVPLATFORMLANGUAGE_EXPORT IndexedDUContextHandler {
     }
 };
 
+struct DeclarationTopContextExtractor {
+  inline static IndexedTopDUContext extract(const IndexedDeclaration& decl) {
+    return decl.indexedTopContext();
+  }
+};
+
+struct DUContextTopContextExtractor {
+  inline static IndexedTopDUContext extract(const IndexedDUContext& ctx) {
+    return ctx.indexedTopContext();
+  }
+};
+
+KDEVPLATFORMLANGUAGE_EXPORT extern Utils::BasicSetRepository recursiveImportCacheRepository;
+
+struct KDEVPLATFORMLANGUAGE_EXPORT RecursiveImportCacheRepository {
+  inline static Utils::BasicSetRepository* repository() {
+    return &recursiveImportCacheRepository;
+  }
+};
+
 /**
  * Global symbol-table that is stored to disk, and allows retrieving declarations that currently are not loaded to memory.
  * */
@@ -110,14 +130,19 @@ class KDEVPLATFORMLANGUAGE_EXPORT IndexedDUContextHandler {
     /// Destructor.
     ~PersistentSymbolTable();
 
+    ///Adds declaration @p declaration with id @p id to the symbol table
+    ///@warning DUChain must be write locked
     void addDeclaration(const IndexedQualifiedIdentifier& id, const IndexedDeclaration& declaration);
 
+    ///Adds declaration @p declaration with id @p id to the symbol table
+    ///@warning DUChain must be write locked
     void removeDeclaration(const IndexedQualifiedIdentifier& id, const IndexedDeclaration& declaration);
 
     ///Retrieves all the declarations for a given IndexedQualifiedIdentifier in an efficient way.
     ///@param id The IndexedQualifiedIdentifier for which the declarations should be retrieved
     ///@param count A reference that will be filled with the count of retrieved declarations
     ///@param declarations A reference to a pointer, that will be filled with a pointer to the retrieved declarations.
+    ///@warning DUChain must be read locked as long as the returned data is used
     void declarations(const IndexedQualifiedIdentifier& id, uint& count, const IndexedDeclaration*& declarations) const;
 
     typedef ConstantConvenientEmbeddedSet<IndexedDeclaration, IndexedDeclarationHandler> Declarations;
@@ -125,31 +150,26 @@ class KDEVPLATFORMLANGUAGE_EXPORT IndexedDUContextHandler {
     ///Retrieves all the declarations for a given IndexedQualifiedIdentifier in an efficient way, and returns
     ///them in a structure that is more convenient than declarations().
     ///@param id The IndexedQualifiedIdentifier for which the declarations should be retrieved
+    ///@warning DUChain must be read locked as long as the returned data is used
     Declarations getDeclarations(const IndexedQualifiedIdentifier& id) const;
 
+    typedef Utils::StorableSet<IndexedTopDUContext, IndexedTopDUContextIndexConversion, RecursiveImportCacheRepository, true> CachedIndexedRecursiveImports;
     
-    void addContext(const IndexedQualifiedIdentifier& id, const IndexedDUContext& context);
+    typedef ConvenientEmbeddedSetTreeFilterIterator<IndexedDeclaration, IndexedDeclarationHandler, IndexedTopDUContext, CachedIndexedRecursiveImports, DeclarationTopContextExtractor> FilteredDeclarationIterator;
+    ///Retrieves an iterator to all declarations of the given id, filtered by the visilibity given through @param visibility
+    ///This is very efficient since it uses a cache
+    ///The returned iterator is valid as long as the duchain read lock is held
+    FilteredDeclarationIterator getFilteredDeclarations(const IndexedQualifiedIdentifier& id, const TopDUContext::IndexedRecursiveImports& visibility) const;
 
-    void removeContext(const IndexedQualifiedIdentifier& id, const IndexedDUContext& context);
-
-    ///Retrieves all the contexts for a given IndexedQualifiedIdentifier in an efficient way.
-    ///@param id The IndexedQualifiedIdentifier for which the contexts should be retrieved
-    ///@param count A reference that will be filled with the count of retrieved contexts
-    ///@param contexts A reference to a pointer, that will be filled with a pointer to the retrieved contexts.
-    void contexts(const IndexedQualifiedIdentifier& id, uint& count, const IndexedDUContext*& contexts) const;
-    
-    typedef ConstantConvenientEmbeddedSet<IndexedDUContext, IndexedDUContextHandler> Contexts;
-
-    ///Retrieves all the contexts for a given IndexedQualifiedIdentifier in an efficient way, and returns them
-    ///in a more user-friendly structure then contexs().
-    ///@param id The IndexedQualifiedIdentifier for which the contexts should be retrieved
-    Contexts getContexts(const IndexedQualifiedIdentifier& id) const;
-    
     static PersistentSymbolTable& self();
 
     //Very expensive: Checks for problems in the symbol table
     void selfAnalysis();
     
+    //Clears the internal cache. Should be called regularly to save memory
+    //The duchain must be read-locked
+    void clearCache();
+    
     private:
       class PersistentSymbolTablePrivate* d;
   };
