@@ -1,6 +1,5 @@
 /* This file is part of KDevelop
-    Copyright 2006 Roberto Raggi <roberto@kdevelop.org>
-    Copyright 2006 Hamish Rodda <rodda@kde.org>
+    Copyright 2007-2009 David Nolden <david.nolden.kdevelop@art-master.de>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,6 +20,7 @@
 #define INDEXEDTYPE_H
 
 #include "abstracttype.h"
+#include <language/duchain/referencecounting.h>
 
 namespace KDevelop
 {
@@ -30,19 +30,34 @@ namespace KDevelop
  *
  * IndexedType is a class which references a type by an index.
  * This way the type can be stored to disk.
+ *
+ * This class does "disk reference counting"
+ * @warning Do not use this after QCoreApplication::aboutToQuit() has been emitted, items that are not disk-referenced will be invalid at that point
  */
-class KDEVPLATFORMLANGUAGE_EXPORT IndexedType {
+class KDEVPLATFORMLANGUAGE_EXPORT IndexedType : public ReferenceCountManager {
   public:
     /// Constructor.
-    IndexedType(uint index = 0) : m_index(index) {
-    }
+    IndexedType(const IndexedType& rhs);
+    explicit IndexedType(uint index = 0);
+    
+    ~IndexedType();
+    
+    IndexedType& operator=(const IndexedType& rhs);
 
     /**
      * Access the type.
      *
      * \returns the type pointer, or null if this index is invalid.
      */
-    AbstractType::Ptr type() const;
+    AbstractType::Ptr abstractType() const;
+
+    /**
+     * Access the type, dynamically casted to the type you provide.
+     *
+     * \returns the type pointer, or null if this index is invalid.
+     */
+    template<class T>
+    TypePtr<T> type() const { return TypePtr<T>::dynamicCast(abstractType()); }
 
     /// Determine if the type is valid. \returns true if valid, otherwise false.
     bool isValid() const {
@@ -75,6 +90,7 @@ class KDEVPLATFORMLANGUAGE_EXPORT IndexedType {
     }
 
   private:
+    ///This class must _never_ hold more than one unsigned integer
     uint m_index;
 };
 
