@@ -51,11 +51,12 @@ public:
     enum Severity {
         Error,
         Warning,
-        Hint        //For implementation-helpers and such stuff
+        Hint        //For implementation-helpers and such stuff. Is not highlighted if the user disables the "highlight semantic problems" option
     };
 
     ProblemData()
         : source(Unknown)
+        , severity(Error)
     {
     }
 
