@@ -62,7 +62,6 @@
 #include <language/interfaces/iquickopen.h>
 #include <interfaces/iplugincontroller.h>
 #include <sublime/mainwindow.h>
-#include <language/highlighting/colorcache.h>
 
 const unsigned int highlightingTimeout = 150;
 
@@ -393,31 +392,33 @@ void ContextBrowserPlugin::clearMouseHover() {
   m_mouseHoverDocument.clear();
 }
 
-
 Attribute::Ptr highlightedUseAttribute(bool /*mouseHighlight*/, bool bold) {
   if(bold) {
     static Attribute::Ptr standardBoldAttribute = Attribute::Ptr();
     if( !standardBoldAttribute ) {
       standardBoldAttribute= Attribute::Ptr( new Attribute() );
       standardBoldAttribute->setBackgroundFillWhitespace(true);
-      
-      standardBoldAttribute->setBackground(QColor(255, 255, 0, 100));//QApplication::palette().toolTipBase());
+
+      // mixing (255, 255, 0, 100) with white yields this:
+      standardBoldAttribute->setBackground(QColor(251, 250, 150));
       standardBoldAttribute->setFontBold(true);
+
+      // force a foreground color to overwrite default Kate highlighting, i.e. of Q_OBJECT or similar
+      // foreground color could change, hence apply it everytime
+      standardBoldAttribute->setForeground(QColor(0, 0, 0, 255)); //Don't use alpha here, as kate uses the alpha only to blend with the document background color
     }
-    // force a foreground color to overwrite default Kate highlighting, i.e. of Q_OBJECT or similar
-    // foreground color could change, hence apply it everytime
-    standardBoldAttribute->setForeground(ColorCache::self()->foregroundColor());
     return standardBoldAttribute;
   }else{
     static Attribute::Ptr standardAttribute = Attribute::Ptr();
     if( !standardAttribute ) {
       standardAttribute = Attribute::Ptr( new Attribute() );
       standardAttribute->setBackgroundFillWhitespace(true);
-      standardAttribute->setBackground(QColor(255, 255, 0, 100));//QApplication::palette().toolTipBase());
+      // mixing (255, 255, 0, 100) with white yields this:
+      standardAttribute->setBackground(QColor(251, 250, 150));
+      // force a foreground color to overwrite default Kate highlighting, i.e. of Q_OBJECT or similar
+      // foreground color could change, hence apply it everytime
+      standardAttribute->setForeground(QColor(0, 0, 0, 255)); //Don't use alpha here, as kate uses the alpha only to blend with the document background color
     }
-    // force a foreground color to overwrite default Kate highlighting, i.e. of Q_OBJECT or similar
-    // foreground color could change, hence apply it everytime
-    standardAttribute->setForeground(ColorCache::self()->foregroundColor());
     return standardAttribute;
   }
 }
@@ -440,11 +441,12 @@ Attribute::Ptr highlightedSpecialObjectAttribute() {
   if( !standardAttribute ) {
     standardAttribute = Attribute::Ptr( new Attribute() );
     standardAttribute->setBackgroundFillWhitespace(true);
-    standardAttribute->setBackground(QColor(90, 255, 0, 100));//QApplication::palette().toolTipBase());
+    // mixing (90, 255, 0, 100) with white yields this:
+    standardAttribute->setBackground(QColor(190, 255, 155));
+    // force a foreground color to overwrite default Kate highlighting, i.e. of Q_OBJECT or similar
+    // foreground color could change, hence apply it everytime
+    standardAttribute->setForeground(QColor(0, 0, 0, 255)); //Don't use alpha here, as kate uses the alpha only to blend with the document background color
   }
-  // force a foreground color to overwrite default Kate highlighting, i.e. of Q_OBJECT or similar
-  // foreground color could change, hence apply it everytime
-  standardAttribute->setForeground(ColorCache::self()->foregroundColor());
   return standardAttribute;
 }
 
