@@ -63,7 +63,7 @@ K_EXPORT_PLUGIN(GenericSupportFactory(KAboutData("kdevgenericmanager","kdevgener
 GenericProjectManager::IncludeRules getIncludeRules(KDevelop::IProject* project) {
     KConfigGroup filtersConfig = project->projectConfiguration()->group("Filters");
     QStringList includes = filtersConfig.readEntry("Includes", QStringList("*"));
-    QStringList excludes = filtersConfig.readEntry("Excludes", QStringList("*/.*"));
+    QStringList excludes = filtersConfig.readEntry("Excludes", QStringList() << "*/.*" << "*~");
 
     return qMakePair(includes, excludes);
 }
@@ -422,7 +422,7 @@ bool GenericProjectManager::removeFolder( KDevelop::ProjectFolderItem * folder )
     kDebug() << "removing folder" << folder->url();
     KDevelop::ProjectFolderItem* parent = getParentFolder(folder);
     stopWatcher(parent);
-    const bool success = KDevelop::removeUrl(folder->url(), true);
+    const bool success = KDevelop::removeUrl(parent->project(), folder->url(), true);
     if ( success ) {
         folder->parent()->removeRow( folder->row() );
     }
@@ -435,7 +435,7 @@ bool GenericProjectManager::removeFile( KDevelop::ProjectFileItem * file )
     kDebug() << "removing file" << file->url();
     KDevelop::ProjectFolderItem* parent = getParentFolder(file);
     stopWatcher(parent);
-    const bool success = KDevelop::removeUrl(file->url(), false);
+    const bool success = KDevelop::removeUrl(file->project(), file->url(), false);
     if ( success ) {
         file->parent()->removeRow( file->row() );
     }
