@@ -27,11 +27,8 @@
 #include <kaboutdata.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kio/netaccess.h>
-#include <kio/copyjob.h>
 #include <kparts/mainwindow.h>
 #include <kparts/componentfactory.h>
-#include <KTemporaryFile>
 
 #include <project/projectmodel.h>
 #include <project/projectbuildsetmodel.h>
@@ -100,28 +97,28 @@ ProjectManagerViewPlugin::ProjectManagerViewPlugin( QObject *parent, const QVari
     d->m_buildAll->setIcon(KIcon("run-build"));
     connect( d->m_buildAll, SIGNAL(triggered()), this, SLOT(buildAllProjects()) );
     actionCollection()->addAction( "project_buildall", d->m_buildAll );
-    d->m_build = new KAction( i18n("Build"), this );
+    d->m_build = new KAction( i18n("Build Selection"), this );
     d->m_build->setShortcut( Qt::Key_F8 );
     d->m_build->setIcon(KIcon("run-build"));
     d->m_build->setEnabled( false );
     connect( d->m_build, SIGNAL(triggered()), this, SLOT(buildProjectItems()) );
     actionCollection()->addAction( "project_build", d->m_build );
-    d->m_install = new KAction( i18n("Install"), this );
+    d->m_install = new KAction( i18n("Install Selection"), this );
     d->m_install->setIcon(KIcon("run-build-install"));
     d->m_install->setEnabled( false );
     connect( d->m_install, SIGNAL(triggered()), this, SLOT(installProjectItems()) );
     actionCollection()->addAction( "project_install", d->m_install );
-    d->m_clean = new KAction( i18n("Clean"), this );
+    d->m_clean = new KAction( i18n("Clean Selection"), this );
     d->m_clean->setIcon(KIcon("run-build-clean"));
     d->m_clean->setEnabled( false );
     connect( d->m_clean, SIGNAL(triggered()), this, SLOT(cleanProjectItems()) );
     actionCollection()->addAction( "project_clean", d->m_clean );
-    d->m_configure = new KAction( i18n("Configure"), this );
+    d->m_configure = new KAction( i18n("Configure Selection"), this );
     d->m_configure->setIcon(KIcon("run-build-configure"));
     d->m_configure->setEnabled( false );
     connect( d->m_configure, SIGNAL(triggered()), this, SLOT(configureProjectItems()) );
     actionCollection()->addAction( "project_configure", d->m_configure );
-    d->m_prune = new KAction( i18n("Prune"), this );
+    d->m_prune = new KAction( i18n("Prune Selection"), this );
     d->m_prune->setIcon(KIcon("run-build-prune"));
     d->m_prune->setEnabled( false );
     connect( d->m_prune, SIGNAL(triggered()), this, SLOT(pruneProjectItems()) );
@@ -451,10 +448,6 @@ void ProjectManagerViewPlugin::createFolderFromContextMenu( )
             if (!name.isEmpty()) {
                 KUrl url = item->folder()->url();
                 url.addPath( name );
-                if ( !KIO::NetAccess::mkdir( url, window ) ) {
-                    KMessageBox::error( window, i18n( "Cannot create folder." ) );
-                    continue;
-                }
                 item->project()->projectFileManager()->addFolder( url, item->folder() );
             }
         }
@@ -466,19 +459,6 @@ void ProjectManagerViewPlugin::removeFromContextMenu()
     foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
     {
         if ( item->folder() || item->file() ) {
-            QWidget* window(ICore::self()->uiController()->activeMainWindow()->window());
-            int q=KMessageBox::questionYesNo(window,
-                item->folder() ? i18n("Do you want to remove the directory from the filesystem too?")
-                               : i18n("Do you want to remove the file from the filesystem too?"));
-            if(q==KMessageBox::Yes)
-            {
-                if ( !KIO::NetAccess::del( item->folder() ? item->folder()->url() : item->file()->url(), window ) ) {
-                    KMessageBox::error( window,
-                        item->folder() ? i18n( "Cannot remove folder." )
-                                       : i18n( "Cannot remove the file." ) );
-                    continue;
-                }
-            }
             if ( item->folder() ) {
                 item->project()->projectFileManager()->removeFolder(item->folder());
             } else {
@@ -527,23 +507,6 @@ ProjectFileItem* createFile(const ProjectFolderItem* item)
     KUrl url=item->url();
     url.addPath( name );
 
-    if (KIO::NetAccess::exists( url, KIO::NetAccess::SourceSide, window )) {
-        KMessageBox::error( window, i18n( "This file exists already." ) );
-        return 0;
-    }
-
-    {
-        KTemporaryFile temp;
-        if ( !temp.open() || temp.write("\n") == -1 ) {
-            KMessageBox::error( window, i18n( "Cannot create temporary file." ) );
-            return 0;
-        }
-        if ( !KIO::NetAccess::upload( temp.fileName(), url, window ) ) {
-            KMessageBox::error( window, i18n( "Cannot create file." ) );
-            return 0;
-        }
-    }
-
     ProjectFileItem* ret=item->project()->projectFileManager()->addFile( url, item->folder() );
     ICore::self()->documentController()->openDocument( url );
     return ret;
