@@ -39,6 +39,8 @@
 #include "interfaces/iprojectfilemanager.h"
 #include <KIO/NetAccess>
 #include <language/duchain/indexedstring.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 namespace KDevelop
 {
@@ -332,6 +334,7 @@ void ProjectFolderItem::setUrl( const KUrl& url )
     d->m_url = url;
     d->m_folderName = d->m_url.fileName();
     setText( d->m_folderName );
+    setToolTip( text() );
 }
 
 bool ProjectFolderItem::hasFileOrFolder(const QString& name) const
@@ -376,6 +379,7 @@ void ProjectFolderItem::setProjectRoot(bool isRoot)
 	Q_D(ProjectFolderItem);
 	d->m_isProjectRoot=isRoot;
 	setText(project()->name());
+        setToolTip( text() );
 }
 
 bool ProjectFolderItem::isProjectRoot() const
@@ -386,7 +390,7 @@ bool ProjectFolderItem::isProjectRoot() const
 
 void ProjectFolderItem::setData(const QVariant& value, int role)
 {
-    if(role==Qt::EditRole) {
+    if(role==Qt::EditRole && value != data(role)) {
         KUrl dest = url().upUrl();
         dest.addPath(value.toString());
         bool ret=!value.toString().contains('/');
@@ -396,6 +400,8 @@ void ProjectFolderItem::setData(const QVariant& value, int role)
         ret = ret && project()->projectFileManager()->renameFolder(this, dest);
         if(ret)
             emitDataChanged();
+        else
+            KMessageBox::error(0, i18n("The name for '%1' could not be changed", url().prettyUrl()), i18n("Project Management"));
     } else
         ProjectBaseItem::setData(value, role);
 }
@@ -424,7 +430,7 @@ ProjectFileItem::~ProjectFileItem()
 
 void ProjectFileItem::setData(const QVariant& value, int role)
 {
-    if(role==Qt::EditRole) {
+    if(role==Qt::EditRole && value != data(role)) {
         KUrl dest = url().upUrl();
         dest.addPath(value.toString());
         bool ret=!value.toString().contains('/');
@@ -434,6 +440,8 @@ void ProjectFileItem::setData(const QVariant& value, int role)
         ret = ret && project()->projectFileManager()->renameFile(this, dest);
         if(ret)
             emitDataChanged();
+        else
+            KMessageBox::error(0, i18n("The name for '%1' could not be changed", url().prettyUrl()), i18n("Project Management"));
     } else
         ProjectBaseItem::setData(value, role);
 }
@@ -460,6 +468,7 @@ void ProjectFileItem::setUrl( const KUrl& url )
     d->m_url = url;
     d->m_fileName = d->m_url.fileName();
     setText( d->m_fileName );
+    setToolTip( text() );
     setIcon(KIcon(KMimeType::findByUrl(url, 0, false, true)->iconName(url)));
 }
 
@@ -484,6 +493,7 @@ ProjectTargetItem::ProjectTargetItem( IProject* project, const QString &name, QS
     Q_D(ProjectTargetItem);
     d->project = project;
     setText( name );
+    setToolTip( text() );
     setParent( parent );
     setIcon( KIcon("system-run") );
 }
