@@ -54,6 +54,7 @@
 #include "debugcontroller.h"
 #include "kdevplatformversion.h"
 #include "workingsetcontroller.h"
+#include <KMessageBox>
 
 namespace KDevelop {
 
@@ -87,14 +88,14 @@ CorePrivate::CorePrivate(Core *core):
 {
 }
 
-void CorePrivate::initialize(Core::Setup mode)
+bool CorePrivate::initialize(Core::Setup mode)
 {
     m_mode=mode;
     if( !sessionController )
     {
         sessionController = new SessionController(m_core);
     }
-    if( !workingSetController )
+    if( !workingSetController && !(mode & Core::NoUi) )
     {
         workingSetController = new WorkingSetController(m_core);
     }
@@ -161,6 +162,13 @@ void CorePrivate::initialize(Core::Setup mode)
 
     kDebug() << "initializing ui controller";
     sessionController->initialize();
+    
+    if(!sessionController->lockSession())
+    {
+        KMessageBox::error(0, i18n("This session is already active in another running instance"));
+        return false;
+    }
+    
     if(!(mode & Core::NoUi)) uiController->initialize();
     languageController->initialize();
     projectController->initialize();
@@ -177,10 +185,10 @@ void CorePrivate::initialize(Core::Setup mode)
 
     kDebug() << "loading session plugins";
     pluginController->initialize();
-    workingSetController->initialize();
 
     if(!(mode & Core::NoUi))
     {
+        workingSetController->initialize();
         /* Need to do this after everything else is loaded.  It's too
             hard to restore position of views, and toolbars, and whatever
             that are not created yet.  */
@@ -192,6 +200,8 @@ void CorePrivate::initialize(Core::Setup mode)
     selectionController->initialize();
     documentationController->initialize();
     debugController->initialize();
+    
+    return true;
 }
 CorePrivate::~CorePrivate()
 {
@@ -211,16 +221,21 @@ CorePrivate::~CorePrivate()
 }
 
 
-void Core::initialize(KSplashScreen* splash, Setup mode)
+bool Core::initialize(KSplashScreen* splash, Setup mode)
 {
     if (m_self)
-        return;
+        return true;
 
     m_self = new Core();
-    m_self->d->initialize(mode);
+    bool ret = m_self->d->initialize(mode);
     if( splash ) {
         QTimer::singleShot( 200, splash, SLOT(deleteLater()) );
     }
+    
+    if(ret)
+        emit m_self->initializationCompleted();
+    
+    return ret;
 }
 
 Core *KDevelop::Core::self()
@@ -265,7 +280,9 @@ void Core::cleanup()
         d->selectionController->cleanup();
         // Save the layout of the ui here, so run it first
         d->uiController->cleanup();
-        d->workingSetController->cleanup();
+
+        if (d->workingSetController)
+            d->workingSetController->cleanup();
 
         /* Must be called before projectController->cleanup(). */
         // Closes all documents (discards, as already saved if the user wished earlier)
