@@ -366,7 +366,12 @@ void DebugController::debuggerStateChanged(KDevelop::IDebugSession::DebuggerStat
         if (session == m_currentSession) {
             m_currentSession = 0;
             emit currentSessionChanged(0);
-            ICore::self()->uiController()->switchToArea("code", IUiController::ThisWindow);
+            Sublime::MainWindow* mainWindow = Core::self()->uiControllerInternal()->activeSublimeWindow();
+            if (mainWindow->area()->objectName() != "code") {
+                QString workingSet = mainWindow->area()->workingSet();
+                ICore::self()->uiController()->switchToArea("code", IUiController::ThisWindow);
+                mainWindow->area()->setWorkingSet(workingSet);
+            }
             ICore::self()->uiController()->findToolView(i18n("Debug"), 0, IUiController::Raise);
         }
         session->deleteLater();
