@@ -68,6 +68,7 @@ struct DocumentControllerPrivate {
     DocumentControllerPrivate(DocumentController* c)
         : controller(c)
         , fileOpenRecent(0)
+        , globalTextEditorInstance(0)
     {
     }
 
@@ -166,8 +167,6 @@ struct DocumentControllerPrivate {
             previousActivePosition = previousActiveDocument->textDocument()->activeView()->cursorPosition();
         
 
-        UiController *uiController = Core::self()->uiControllerInternal();
-
         QString _encoding = encoding;
         
         KUrl url = inputUrl;
@@ -405,6 +404,7 @@ struct DocumentControllerPrivate {
     QPointer<KAction> closeAll;
     QPointer<KAction> closeAllOthers;
     KRecentFilesAction* fileOpenRecent;
+    KTextEditor::Document* globalTextEditorInstance;
 
 /*    HistoryEntry createHistoryEntry();
     void addHistoryEntry();
@@ -692,15 +692,15 @@ QList< IDocument * > KDevelop::DocumentController::documentsExclusivelyInWindow(
 {
     // Gather a list of all documents which have views only in the given main window
     QList<IDocument*> checkSave;
+    
     foreach (IDocument* doc, openDocuments()) {
         if (Sublime::Document* sdoc = dynamic_cast<Sublime::Document*>(doc)) {
             bool inOtherWindow = false;
 
             foreach (Sublime::View* view, sdoc->views()) {
-                if (view->hasWidget() && view->widget()->window() != mw) {
-                    inOtherWindow = true;
-                    break;
-                }
+                foreach(Sublime::MainWindow* window, Core::self()->uiControllerInternal()->mainWindows())
+                    if(window != mw && window->containsView(view))
+                        inOtherWindow = true;
             }
 
             if (!inOtherWindow)
@@ -833,6 +833,14 @@ IDocumentFactory* DocumentController::factory(const QString& mime) const
     return d->factories.value(mime);
 }
 
+KTextEditor::Document* DocumentController::globalTextEditorInstance()
+{
+    if(!d->globalTextEditorInstance)
+        d->globalTextEditorInstance = Core::self()->partControllerInternal()->createTextPart(QString());
+    return d->globalTextEditorInstance;
+}
+
+
 }
 
 #include "documentcontroller.moc"
