@@ -202,14 +202,14 @@ QList<ILanguage*> LanguageController::languagesForUrl(const KUrl &url)
 
         ///non-crashy part: Use the mime-types of known languages
         ///Very inefficient right now
+        QRegExp exp("", Qt::CaseInsensitive, QRegExp::Wildcard);
         for(LanguageControllerPrivate::MimeTypeCache::const_iterator it = d->mimeTypeCache.constBegin(); it != d->mimeTypeCache.constEnd(); ++it) {
             foreach(QString pattern, it.key()->patterns()) {
                 if(pattern.startsWith('*'))
                 pattern = pattern.mid(1);
 
-                QRegExp exp(pattern, Qt::CaseInsensitive, QRegExp::Wildcard);
+                exp.setPattern(pattern);
                 if(int position = exp.indexIn(fileName)) {
-                    
                     if(position != -1 && exp.matchedLength() + position == fileName.length())
                         languages << *it;
                 }
@@ -233,11 +233,15 @@ QList<ILanguage*> LanguageController::languagesForUrl(const KUrl &url)
             QList<IPlugin*> supports = Core::self()->pluginController()->
                 allPluginsForExtension("ILanguageSupport", constraints);
 
-            foreach (IPlugin *support, supports) {
-                ILanguageSupport* languageSupport = support->extension<ILanguageSupport>();
-                kDebug() << "language-support:" << languageSupport;
-                if(languageSupport)
-                    return languages << d->addLanguageForSupport(languageSupport);
+            if (supports.isEmpty()) {
+                d->languageCache.insert(mimeType->name(), QList<ILanguage*>());
+            } else {
+                foreach (IPlugin *support, supports) {
+                    ILanguageSupport* languageSupport = support->extension<ILanguageSupport>();
+                    kDebug() << "language-support:" << languageSupport;
+                    if(languageSupport)
+                        return languages << d->addLanguageForSupport(languageSupport);
+                }
             }
         }
     }
