@@ -87,12 +87,19 @@ class ProjectProgress : public QObject, public IStatus
         void showErrorMessage(const QString & message, int timeout = 0);
         void hideProgress(KDevelop::IStatus*);
         void showProgress(KDevelop::IStatus*,int minimum, int maximum, int value);
+        
+    private:
+        QTimer* m_timer;
 };
     
     
     
 ProjectProgress::ProjectProgress()
 {
+    m_timer = new QTimer(this);
+    m_timer->setSingleShot( true );
+    m_timer->setInterval( 1000 );
+    connect(m_timer, SIGNAL(timeout()),SLOT(slotClean()));
 }
 
 ProjectProgress::~ProjectProgress()
@@ -101,7 +108,7 @@ ProjectProgress::~ProjectProgress()
 
 QString ProjectProgress::statusName() const
 {
-    return i18n("Loading Project ") + projectName;
+    return i18n("Loading Project %1", projectName);
 }
 
 void ProjectProgress::setBuzzy()
@@ -109,7 +116,7 @@ void ProjectProgress::setBuzzy()
     kDebug() << "showing busy prorgess" << statusName();
     // show an indeterminate progressbar
     emit showProgress(this, 0,0,0);
-    emit showMessage(this, i18n("Loading") + " " + projectName);
+    emit showMessage(this, i18n("Loading %1", projectName));
 }
 
 
@@ -118,11 +125,7 @@ void ProjectProgress::setDone()
     kDebug() << "showing done progress" << statusName();
     // first show 100% bar for a second, then hide.
     emit showProgress(this, 0,1,1);
-    QTimer* t = new QTimer;
-    t->setSingleShot( true );
-    t->setInterval( 1000 );
-    connect(t, SIGNAL(timeout()),SLOT(slotClean()));
-    t->start();
+    m_timer->start();
 }
 
 void ProjectProgress::slotClean()
@@ -147,14 +150,14 @@ public:
     KSharedConfig::Ptr m_cfg;
     IProject *project;
     QSet<KDevelop::IndexedString> fileSet;
-    bool reloading;
+    bool loading;
     bool scheduleReload;
     ProjectProgress* progress;
 
     void reloadDone()
     {
         progress->setDone();
-        reloading = false;
+        loading = false;
         Core::self()->projectController()->projectModel()->appendRow(topItem);
         if (scheduleReload) {
             scheduleReload = false;
@@ -234,6 +237,7 @@ public:
         progress->setDone();
         ProjectController* projCtrl = Core::self()->projectControllerInternal();
         
+        loading=false;
         if(job->errorText().isEmpty()) {
             projCtrl->projectModel()->appendRow(topItem);
             projCtrl->projectImportingFinished( project );
@@ -432,7 +436,7 @@ Project::Project( QObject *parent )
     d->topItem = 0;
     d->tmp = 0;
     d->vcsPlugin = 0;
-    d->reloading = false;
+    d->loading = false;
     d->scheduleReload = false;
     d->progress = new ProjectProgress;
     Core::self()->uiController()->registerStatus( d->progress );
@@ -472,11 +476,11 @@ const KUrl Project::folder() const
 
 void Project::reloadModel()
 {
-    if (d->reloading) {
+    if (d->loading) {
         d->scheduleReload = true;
         return;
     }
-    d->reloading = true;
+    d->loading = true;
     d->fileSet.clear();
 
     ProjectModel* model = Core::self()->projectController()->projectModel();
@@ -485,7 +489,7 @@ void Project::reloadModel()
     IProjectFileManager* iface = d->manager->extension<IProjectFileManager>();
     if (!d->importTopItem(iface))
     {
-            d->reloading = false;
+            d->loading = false;
             d->scheduleReload = false;
             return;
     }
@@ -518,6 +522,7 @@ bool Project::open( const KUrl& projectFileUrl_ )
         return false;
     }
 
+    d->loading=true;
     d->loadVersionControlPlugin(projectGroup);
     d->progress->setBuzzy();
     KJob* importJob = iface->createImportJob(d->topItem );
@@ -668,6 +673,11 @@ QSet<IndexedString> Project::fileSet() const
     return d->fileSet;
 }
 
+bool Project::isReady() const
+{
+    return !d->loading;
+}
+
 } // namespace KDevelop
 
 #include "project.moc"
