@@ -211,6 +211,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
         else
         {
             parent = d->m_indexSplitters[index->parent()];
+            Q_ASSERT(parent);
             kDebug() << "adding new splitter to" << parent;
             splitter = new QSplitter(parent);
             d->m_indexSplitters[index] = splitter;
@@ -231,6 +232,8 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
             connect(container, SIGNAL(activateView(Sublime::View*)), d->m_mainWindow, SLOT(activateView(Sublime::View*)));
             connect(container, SIGNAL(tabContextMenuRequested(Sublime::View*,KMenu*)),
                     d->m_mainWindow, SLOT(tabContextMenuRequested(Sublime::View*,KMenu*)));
+            connect(container, SIGNAL(tabToolTipRequested(Sublime::View*,QPoint)),
+                    d->m_mainWindow, SLOT(tabToolTipRequested(Sublime::View*,QPoint)));
             connect(container, SIGNAL(closeRequest(QWidget*)),
                     d, SLOT(widgetCloseRequest(QWidget*)));
             splitter->addWidget(container);
@@ -364,6 +367,13 @@ slotDockShown(Sublime::View* view, Sublime::Position pos, bool shown)
     area->setShownToolView(pos, id);
 }
 
+void MainWindowPrivate::viewRemovedInternal(AreaIndex* index, View* view)
+{
+    // A formerly non-empty working-set has become empty, and a relayout of the area-selector may be required
+    if(m_mainWindow->area()->views().size() == 0)
+        m_mainWindow->setupAreaSelector();
+}
+
 void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view)
 {
     if(m_leftTabbarCornerWidget) {
@@ -390,6 +400,10 @@ void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view
     emit m_mainWindow->viewAdded( view );
     
     setTabBarLeftCornerWidget(m_leftTabbarCornerWidget);
+    
+    // A formerly empty working-set may become non-empty, and a relayout of the area-selector may be required
+    if(m_mainWindow->area()->views().size() == 1)
+        m_mainWindow->setupAreaSelector();
 }
 
 void Sublime::MainWindowPrivate::raiseToolView(Sublime::View * view)
@@ -418,9 +432,9 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
         widgetToView.remove(view->widget());
     viewContainers.remove(view);
 
+    const bool wasActive = m_mainWindow->activeView() == view;
     if (container->count() > 1)
     {
-        bool wasActive = m_mainWindow->activeView() == view;
         //container is not empty or this is a root index
         //just remove a widget
 		if( view->widget() ) {
@@ -515,7 +529,9 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
     }
 
     setTabBarLeftCornerWidget(m_leftTabbarCornerWidget);
-    m_mainWindow->setActiveView(0L);
+    if ( wasActive ) {
+        m_mainWindow->setActiveView(0L);
+    }
 }
 
 void MainWindowPrivate::toolViewAdded(Sublime::View* /*toolView*/, Sublime::Position position)
