@@ -31,8 +31,8 @@
 #include <kparts/part.h>
 #include <kio/netaccess.h>
 #include <interfaces/iplugincontroller.h>
-#include <tests/common/autotestshell.h>
-#include <shell/testcore.h>
+#include <tests/autotestshell.h>
+#include <tests/testcore.h>
 #include <vcs/interfaces/idistributedversioncontrol.h>
 #include <vcs/interfaces/icentralizedversioncontrol.h>
 #include <vcs/vcsjob.h>
